@@ -12,7 +12,7 @@
 //! time you propagate the error upwards with `up!()`.
 //!
 //! *Throw does not replace existing error handling systems*. The `throw::Error` type has a type
-//! parameter `E` which represents an internal error type stored. `throw::Error` just warps your
+//! parameter `E` which represents an internal error type stored. `throw::Error` just wraps your
 //! error type and stores ErrorPoints alongside it.
 //!
 //! Throw helps you better keep track of your errors. Instead of seeing a generic "No such file or
@@ -216,6 +216,12 @@ impl<E> Error<E> {
     pub fn original_error(&self) -> &E {
         &self.original_error
     }
+    
+    /// Move the original error out.
+    #[inline]
+    pub fn into_origin(self) -> E {
+        self.original_error
+    }
 
     /// Transforms this Error<OldError> into Error<NewError>. This isn't implemented as an Into or
     /// From implementation because it would conflict with the blanket implementations in stdlib.
@@ -270,6 +276,7 @@ macro_rules! up {
         }
     );
 }
+
 #[macro_export]
 macro_rules! throw {
     ($e:expr) => (
